package com.ruoyi.web.controller.pc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TTitle;
import com.ruoyi.system.service.ITTitleService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 职称信息Controller
 * 
 * @author ruoyi
 * @date 2022-08-03
 */
@RestController
@RequestMapping("/system/title")
public class TTitleController extends BaseController
{
    @Autowired
    private ITTitleService tTitleService;

    /**
     * 查询职称信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:title:list')")
    @GetMapping("/list")
    public TableDataInfo list(TTitle tTitle)
    {
        startPage();
        List<TTitle> list = tTitleService.selectTTitleList(tTitle);
        return getDataTable(list);
    }

    /**
     * 导出职称信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:title:export')")
    @Log(title = "职称信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TTitle tTitle)
    {
        List<TTitle> list = tTitleService.selectTTitleList(tTitle);
        ExcelUtil<TTitle> util = new ExcelUtil<TTitle>(TTitle.class);
        util.exportExcel(response, list, "职称信息数据");
    }

    /**
     * 获取职称信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:title:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tTitleService.selectTTitleById(id));
    }

    /**
     * 新增职称信息
     */
    @PreAuthorize("@ss.hasPermi('system:title:add')")
    @Log(title = "职称信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTitle tTitle)
    {
        return toAjax(tTitleService.insertTTitle(tTitle));
    }

    /**
     * 修改职称信息
     */
    @PreAuthorize("@ss.hasPermi('system:title:edit')")
    @Log(title = "职称信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTitle tTitle)
    {
        return toAjax(tTitleService.updateTTitle(tTitle));
    }

    /**
     * 删除职称信息
     */
    @PreAuthorize("@ss.hasPermi('system:title:remove')")
    @Log(title = "职称信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tTitleService.deleteTTitleByIds(ids));
    }
}
