package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.common.constant.UserConstants;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.TRecord;
import com.ruoyi.system.domain.req.PcTPatintQueryByPageReq;
import com.ruoyi.system.domain.resp.PcTPatientQueryByPageResp;
import com.ruoyi.system.mapper.TRecordMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TPatientMapper;
import com.ruoyi.system.domain.TPatient;
import com.ruoyi.system.service.ITPatientService;
import org.springframework.util.ObjectUtils;

/**
 * 患者信息Service业务层处理
 *
 * @author ruoyi
 * @date 2022-08-03
 */
@Service
public class TPatientServiceImpl implements ITPatientService
{
    @Autowired
    private TPatientMapper tPatientMapper;

    @Autowired
    private TRecordMapper tRecordMapper;
    /**
     * 查询患者信息
     *
     * @param id 患者信息主键
     * @return 患者信息
     */
    @Override
    public TPatient selectTPatientById(Long id)
    {
        return tPatientMapper.selectTPatientById(id);
    }

    /**
     * 查询患者信息列表
     *
     * @param tPatient 患者信息
     * @return 患者信息
     */
    @Override
    public List<TPatient> selectTPatientList(TPatient tPatient)
    {
        return tPatientMapper.selectTPatientList(tPatient);
    }

    /**
     * 新增患者信息
     *
     * @param tPatient 患者信息
     * @return 结果
     */
    @Override
    public int insertTPatient(TPatient tPatient)
    {
        tPatient.setCreateTime(DateUtils.getNowDate());
        return tPatientMapper.insertTPatient(tPatient);
    }

    /**
     * 修改患者信息
     *
     * @param tPatient 患者信息
     * @return 结果
     */
    @Override
    public int updateTPatient(TPatient tPatient)
    {
        tPatient.setUpdateTime(DateUtils.getNowDate());
        return tPatientMapper.updateTPatient(tPatient);
    }

    /**
     * 批量删除患者信息
     *
     * @param ids 需要删除的患者信息主键
     * @return 结果
     */
    @Override
    public int deleteTPatientByIds(Long[] ids)
    {
        return tPatientMapper.deleteTPatientByIds(ids);
    }

    /**
     * 删除患者信息信息
     *
     * @param id 患者信息主键
     * @return 结果
     */
    @Override
    public int deleteTPatientById(Long id)
    {
        return tPatientMapper.deleteTPatientById(id);
    }

    @Override
    public List<PcTPatientQueryByPageResp> queryByPage(PcTPatintQueryByPageReq pcTPatintQueryByPageReq) {
        Long hospitalId = pcTPatintQueryByPageReq.getHospitalId();
        TRecord record = new TRecord();
        record.setStatus("1");
        record.setHospitalId(hospitalId);
        List<PcTPatientQueryByPageResp> pcTPatientQueryByPageResps = tPatientMapper.queryByPage(pcTPatintQueryByPageReq);
        pcTPatientQueryByPageResps.stream().forEach(a ->{
            record.setPatientId(a.getId());
            List<TRecord> tRecords = tRecordMapper.selectTRecordDoctorPatientFirst(record);
            //最后一次/初次就诊时间
            if (!ObjectUtils.isEmpty(tRecords)){
                a.setLatestTime(tRecords.get(0).getCreateTime());
                a.setFirstTime(tRecords.get(tRecords.size()-1).getCreateTime());
            }
            //诊断次数
            a.setCountRecords(tRecords.size());
        });
        return pcTPatientQueryByPageResps;
    }

    @Override
    public String checkPhoneUnique(String phone)
    {
        int count = tPatientMapper.checkPhoneUnique(phone);
        if (count > 0)
        {
            return UserConstants.NOT_UNIQUE;
        }
        return UserConstants.UNIQUE;
    }

    @Override
    public TPatient queryTPatientByPhoneAndName(TPatient tPatient) {
        return tPatientMapper.queryTPatientByPhoneAndName(tPatient);
    }
}
